@@ -85,7 +85,7 @@ static int up_gtp_action_enable_disable(struct up_gtp_action *a, bool enable)
 	switch (a->kind) {
 	case UP_GTP_U_TUNEND:
 		if (g_upf->tunend.mockup) {
-			LOG_UP_GTP_ACTION(a, LOGL_NOTICE, "tunend/mockup active, skipping GTP action %s\n",
+			LOG_UP_GTP_ACTION(a, LOGL_INFO, "tunend/mockup active, skipping GTP action %s\n",
 					  enable ? "enable" : "disable");
 			return 0;
 		}
@@ -111,13 +111,13 @@ static int up_gtp_action_enable_disable(struct up_gtp_action *a, bool enable)
 					  enable ? "enable" : "disable", rc);
 			return rc;
 		}
-		LOG_UP_GTP_ACTION(a, LOGL_NOTICE, "%s tunend on dev %s\n", enable ? "Enabled" : "Disabled",
+		LOG_UP_GTP_ACTION(a, LOGL_INFO, "%s tunend on dev %s\n", enable ? "Enabled" : "Disabled",
 				  gtp_dev->name);
 		return 0;
 
 	case UP_GTP_U_TUNMAP:
 		if (g_upf->tunmap.mockup) {
-			LOG_UP_GTP_ACTION(a, LOGL_NOTICE, "tunmap/mockup active, skipping nftables ruleset %s\n",
+			LOG_UP_GTP_ACTION(a, LOGL_INFO, "tunmap/mockup active, skipping nftables ruleset %s\n",
 					  enable ? "enable" : "disable");
 			return 0;
 		}
@@ -131,7 +131,7 @@ static int up_gtp_action_enable_disable(struct up_gtp_action *a, bool enable)
 					  enable ? "enable" : "disable", rc);
 			return rc;
 		}
-		LOG_UP_GTP_ACTION(a, LOGL_NOTICE, "%s tunmap, nft chain IDs: access--%u-> <-%u--core\n",
+		LOG_UP_GTP_ACTION(a, LOGL_INFO, "%s tunmap, nft chain IDs: access--%u-> <-%u--core\n",
 				  enable ? "Enabled" : "Disabled",
 				  a->tunmap.access.chain_id, a->tunmap.core.chain_id);
 		return 0;
